==> Yahoo-Marketing-3.01.tar.gz: Yahoo-Marketing-3.01/lib/Yahoo/Marketing/Campaign.pm <==
package Yahoo::Marketing::Campaign;
# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
# The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 

use strict; use warnings;

use base qw/Yahoo::Marketing::ComplexType/;

=head1 NAME

Yahoo::Marketing::Campaign - an object to represent a Yahoo Marketing Campaign.

=cut

sub _user_setable_attributes {
    return ( qw/ 
                 ID
                 accountID
                 advancedMatchON
                 campaignOptimizationON
                 contentMatchON
                 description
                 endDate
                 name
                 sponsoredSearchON
                 startDate
                 status
                 watchON
            /  );
}

sub _read_only_attributes {
    return ( qw/
                 createTimestamp
                 deleteTimestamp
                 lastUpdateTimestamp
           / );
}

__PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes, 
                           __PACKAGE__->_read_only_attributes
                         );


1;
=head1 SYNOPSIS

See L<http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/dataObjects.asp> for documentation of the various data objects.


=head2 new

Creates a new instance

=cut

=head1 METHODS

=head2 get/set methods

=over 8

    ID
    accountID
    advancedMatchON
    campaignOptimizationON
    contentMatchON
    description
    endDate
    name
    sponsoredSearchON
    startDate
    status
    watchON

=back

=head2 get (read only) methods

=over 8

    createTimestamp
    deleteTimestamp
    lastUpdateTimestamp

=back

=cut

==> Yahoo-Marketing-4.21.tar.gz: Yahoo-Marketing-4.21/lib/Yahoo/Marketing/Campaign.pm <==
package Yahoo::Marketing::Campaign;
# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
# The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 

use strict; use warnings;

use base qw/Yahoo::Marketing::ComplexType/;

=head1 NAME

Yahoo::Marketing::Campaign - an object to represent a Yahoo Marketing Campaign.

=cut

sub _user_setable_attributes {
    return ( qw/ 
                 ID
                 accountID
                 advancedMatchON
                 contentMatchON
                 description
                 endDate
                 name
                 sponsoredSearchON
                 startDate
                 status
                 watchON
            /  );
}

sub _read_only_attributes {
    return ( qw/
                 campaignOptimizationON
                 createTimestamp
                 deleteTimestamp
                 lastUpdateTimestamp
           / );
}

__PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes, 
                           __PACKAGE__->_read_only_attributes
                         );


1;
=head1 SYNOPSIS

See L<http://searchmarketing.yahoo.com/developer/docs/V4/reference/dataObjects.php> for documentation of the various data objects.


=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 get/set methods

=over 8

    ID
    accountID
    advancedMatchON
    contentMatchON
    description
    endDate
    name
    sponsoredSearchON
    startDate
    status
    watchON

=back

=head2 get (read only) methods

=over 8

    campaignOptimizationON
    createTimestamp
    deleteTimestamp
    lastUpdateTimestamp

=back

=cut
